@@ -23,6 +23,7 @@ static char rcsid[] = "@(#$Id: rclconfig.cpp,v 1.62 2008-10-08 16:15:22 dockes E
 #include <stdio.h>
 #include <errno.h>
 #include <langinfo.h>
+#include <limits.h>
 
 #include <set>
 #include <algorithm>
@@ -243,7 +244,7 @@ void RclConfig::setKeyDir(const string &dir)
     getConfParam("guesscharset", &guesscharset);
 }
 
-bool RclConfig::getConfParam(const std::string &name, int *ivp)
+bool RclConfig::getConfParam(const string &name, int *ivp)
 {
     string value;
     if (!getConfParam(name, value))
@@ -257,7 +258,7 @@ bool RclConfig::getConfParam(const std::string &name, int *ivp)
     return true;
 }
 
-bool RclConfig::getConfParam(const std::string &name, bool *bvp)
+bool RclConfig::getConfParam(const string &name, bool *bvp)
 {
     if (!bvp) 
 	return false;
@@ -270,7 +271,7 @@ bool RclConfig::getConfParam(const std::string &name, bool *bvp)
     return true;
 }
 
-bool RclConfig::getConfParam(const std::string &name, vector<string> *svvp)
+bool RclConfig::getConfParam(const string &name, vector<string> *svvp)
 {
     if (!svvp) 
 	return false;
@@ -280,7 +281,7 @@ bool RclConfig::getConfParam(const std::string &name, vector<string> *svvp)
 	return false;
     return stringToStrings(s, *svvp);
 }
-bool RclConfig::getConfParam(const std::string &name, list<string> *svvp)
+bool RclConfig::getConfParam(const string &name, list<string> *svvp)
 {
     if (!svvp) 
 	return false;
@@ -353,12 +354,35 @@ const string& RclConfig::getDefCharset(bool filename)
     }
 }
 
+bool RclConfig::addLocalFields(map<string, string> *tgt)
+{
+    LOGDEB(("RclConfig::addLocalFields: keydir [%s]\n", m_keydir.c_str()));
+    string sfields;
+    if (tgt == 0 || ! getConfParam("localfields", sfields))
+        return false;
+    // Substitute ':' with '\n' inside the string. There is no way to escape ':'
+    for (string::size_type i = 0; i < sfields.size(); i++)
+        if (sfields[i] == ':')
+            sfields[i] = '\n';
+    // Parse the result with a confsimple and add the results to the metadata
+    ConfSimple conf(sfields, 1, true);
+    list<string> nmlst = conf.getNames("");
+    for (list<string>::const_iterator it = nmlst.begin();
+         it != nmlst.end(); it++) {
+        conf.get(*it, (*tgt)[*it]);
+        LOGDEB(("RclConfig::addLocalFields: [%s] => [%s]\n",
+		(*it).c_str(), (*tgt)[*it].c_str()));
+    }
+    return true;
+}
+
+
 // Get all known document mime values (for indexing). We get them from
 // the mimeconf 'index' submap: values not in there (ie from mimemap
 // or idfile) can't possibly belong to documents in the database.
-std::list<string> RclConfig::getAllMimeTypes()
+list<string> RclConfig::getAllMimeTypes()
 {
-    std::list<string> lst;
+    list<string> lst;
     if (mimeconf == 0)
 	return lst;
     lst = mimeconf->getNames("index");
@@ -496,7 +520,7 @@ bool RclConfig::getMimeCatTypes(const string& cat, list<string>& tps)
     return true;
 }
 
-string RclConfig::getMimeHandlerDef(const std::string &mtype, bool filtertypes)
+string RclConfig::getMimeHandlerDef(const string &mtype, bool filtertypes)
 {
     string hs;
     if (filtertypes && m_rmtstate.needrecompute()) {
@@ -516,13 +540,10 @@ string RclConfig::getMimeHandlerDef(const std::string &mtype, bool filtertypes)
     return hs;
 }
 
-/** 
- * @param whole is like "base value ; attr1 = somthing; attr2 = somethelse"
- * There is no way to escape a semi-colon inside whole
- */
 bool RclConfig::valueSplitAttributes(const string& whole, string& value, 
-                              ConfSimple& attrs)
+				     ConfSimple& attrs)
 {
+    /* There is currently no way to escape a semi-colon */
     string::size_type semicol0 = whole.find_first_of(";");
     value = whole.substr(0, semicol0);
     string attrstr;
@@ -962,9 +983,10 @@ static int ncffiles = sizeof(configfiles) / sizeof(char *);
 bool RclConfig::initUserConfig()
 {
     // Explanatory text
-    char blurb[sizeof(blurb0)+1025];
+    const int bs = sizeof(blurb0)+PATH_MAX+1;
+    char blurb[bs];
     string exdir = path_cat(m_datadir, "examples");
-    sprintf(blurb, blurb0, exdir.c_str());
+    snprintf(blurb, bs, blurb0, exdir.c_str());
 
     // Use protective 700 mode to create the top configuration
     // directory: documents can be reconstructed from index data.
