@@ -145,8 +145,11 @@ class RclConfig {
 	Doesn't depend on the keydir */
     list<string> getDaemSkippedPaths();
 
+    /** conf: Add local fields to target dic */
+    bool addLocalFields(map<string, string> *tgt);
+
     /** 
-     * Check if file name should be ignored because of suffix
+     * mimemap: Check if file name should be ignored because of suffix
      *
      * The list of ignored suffixes is initialized on first call, and
      * not changed for subsequent setKeydirs.
@@ -171,8 +174,11 @@ class RclConfig {
 
     /** mimeconf: get input filter for mimetype */
     string getMimeHandlerDef(const string &mimetype, bool filtertypes=false);
-    /** For lines like: "name = some value; and additional; attributes"
-     * Split the value and store the attributes in a ConfSimple */
+
+    /** For lines like: "name = some value; attr1 = value1; attr2 = val2"
+     * Separate the value and store the attributes in a ConfSimple 
+     * @param whole the raw value. No way to escape a semi-colon in there.
+     */
     bool valueSplitAttributes(const string& whole, string& value, 
                               ConfSimple& attrs);
 
