@@ -9,6 +9,10 @@ class RclExecM:
     noteof  = 0
     eofnext = 1
     eofnow = 2
+
+    noerror = 0
+    subdocerror = 1
+    fileerror = 2
     
     def __init__(self):
         self.myname = os.path.basename(sys.argv[0])
@@ -18,9 +22,19 @@ class RclExecM:
         print >> sys.stderr, "RCLMFILT:", self.myname, ":", s
         if doexit:
             sys.exit(exitvalue)
+
+    def htmlescape(self, txt):
+        txt = txt.replace("<", "&lt;")
+        txt = txt.replace("&", "&amp;")
+        txt = txt.replace('"', "&dquot;")
+        return txt
+
     # Our worker sometimes knows the mime types of the data it sends
     def setmimetype(self, mt):
         self.mimetype = mt
+
+    # Read single parameter from process input: line with param name and size
+    # followed by data.
     def readparam(self):
         s = sys.stdin.readline()
         if s == '':
@@ -46,29 +60,34 @@ class RclExecM:
             paramdata = ""
     
         #self.rclog("paramname [%s] paramsize %d value [%s]" %
-        #      (paramname, paramsize, paramdata))
+        #          (paramname, paramsize, paramdata))
         return (paramname, paramdata)
 
     # Send answer: document, ipath, possible eof.
-    def answer(self, docdata, ipath, iseof = noteof):
+    def answer(self, docdata, ipath, iseof = noteof, iserror = noerror):
 
-        print "Document:", len(docdata)
-        sys.stdout.write(docdata)
+        if iserror != RclExecM.fileerror and iseof != RclExecM.eofnow:
+            print "Document:", len(docdata)
+            sys.stdout.write(docdata)
 
-        if len(ipath):
-            print "Ipath:", len(ipath)
-            sys.stdout.write(ipath)
+            if len(ipath):
+                print "Ipath:", len(ipath)
+                sys.stdout.write(ipath)
 
-        if len(self.mimetype):
-            print "Mimetype:", len(self.mimetype)
-            sys.stdout.write(self.mimetype)
+            if len(self.mimetype):
+                print "Mimetype:", len(self.mimetype)
+                sys.stdout.write(self.mimetype)
 
         # If we're at the end of the contents, say so
-        if iseof == self.eofnow:
+        if iseof == RclExecM.eofnow:
             print "Eofnow: 0"
-        elif iseof == self.eofnext:
+        elif iseof == RclExecM.eofnext:
             print "Eofnext: 0"
-            
+        if iserror == RclExecM.subdocerror:
+            print "Subdocerror: 0"
+        elif iserror == RclExecM.fileerror:
+            print "Fileerror: 0"
+  
         # End of message
         print
         sys.stdout.flush()
@@ -83,11 +102,12 @@ class RclExecM:
         # If we're given a file name, open it. 
         if len(params["filename:"]) != 0:
             if not processor.openfile(params):
-                self.answer("", "", True)
+                self.answer("", "", iserror = RclExecM.fileerror)
                 return
             
         # If we have an ipath, that's what we look for, else ask for next entry
         ipath = ""
+        self.mimetype = ""
         if params.has_key("ipath:") and len(params["ipath:"]):
             ok, data, ipath, eof = processor.getipath(params)
         else:
@@ -96,7 +116,7 @@ class RclExecM:
         if ok:
             self.answer(data, ipath, eof)
         else:
-            self.answer("", "", eof)
+            self.answer("", "", eof, RclExecM.subdocerror)
 
     # Loop on messages from our master
     def mainloop(self, processor):
@@ -116,3 +136,42 @@ class RclExecM:
             # Got message, act on it
             self.processmessage(processor, params)
 
+
+# Common main routine for all python execm filters: either run the
+# normal protocol engine or a local loop to test without recollindex
+def main(proto, extract):
+    if len(sys.argv) == 1:
+        proto.mainloop(extract)
+    else:
+        # Got a file name parameter: TESTING without an execm parent
+        # Loop on all entries or get specific ipath
+        if not extract.openfile({'filename:':sys.argv[1]}):
+            print "Open error"
+            sys.exit(1)
+        ipath = ""
+        if len(sys.argv) == 3:
+            ipath = sys.argv[2]
+
+        if ipath != "":
+            ok, data, ipath, eof = extract.getipath({'ipath:':ipath})
+            if ok:
+                print "== Found entry for ipath %s (mimetype [%s]):" % \
+                      (ipath, proto.mimetype)
+                print data
+                print
+            else:
+                print "Got error, eof %d"%eof
+            sys.exit(0)
+
+        ecnt = 0   
+        while 1:
+            ok, data, ipath, eof = extract.getnext("")
+            if ok:
+                ecnt = ecnt + 1
+                print "== Entry %d ipath %s (mimetype [%s]:" % \
+                      (ecnt, ipath, proto.mimetype)
+#                print data
+                print
+            else:
+                print "Not ok, eof %d" % eof
+                break
