@@ -39,7 +39,7 @@ static char rcsid[] = "@(#$Id: rclmonprc.cpp,v 1.14 2008-11-18 13:25:48 dockes E
 #include "debuglog.h"
 #include "rclmon.h"
 #include "debuglog.h"
-#include "indexer.h"
+#include "recollindex.h"
 #include "pathut.h"
 #include "x11mon.h"
 
@@ -168,24 +168,18 @@ RclConfig *RclMonEventQueue::getConfig()
     return m_data->m_config;
 }
 
-extern int stopindexing;
-
 bool RclMonEventQueue::ok()
 {
     if (m_data == 0) {
 	LOGDEB(("RclMonEventQueue: not ok: bad state\n"));
 	return false;
     }
-    if (!(m_data->m_opts & RCLMON_NOX11) && !x11IsAlive()) {
-	LOGDEB(("RclMonEventQueue: not ok: x11\n"));
-	return false;
-    }
     if (stopindexing) {
 	LOGDEB(("RclMonEventQueue: not ok: stop request\n"));
 	return false;
     }
     if (!m_data->m_ok) {
-	LOGDEB(("RclMonEventQueue: not ok: end from rcv\n"));
+	LOGDEB(("RclMonEventQueue: not ok: queue terminated\n"));
 	return false;
     }
     return true;
@@ -300,20 +294,28 @@ bool startMonitor(RclConfig *conf, int opts)
     LOGDEB(("start_monitoring: entering main loop\n"));
     bool timedout;
     time_t lastauxtime = time(0);
+    time_t lastixtime = lastauxtime;
     bool didsomething = false;
+    const int auxinterval = 60 *60;
+    const int ixinterval = 30;
+
+    list<string> modified;
+    list<string> deleted;
 
     // Set a relatively short timeout for better monitoring of exit requests
     while (rclEQ.wait(2, &timedout)) {
 	// Queue is locked.
 
-	if (!rclEQ.ok()) {
+	// x11IsAlive() can't be called from ok() because both threads call it
+	// and Xlib is not multithreaded.
+        bool x11dead = !(opts & RCLMON_NOX11) && !x11IsAlive();
+        if (x11dead)
+            LOGDEB(("RclMonprc: x11 is dead\n"));
+	if (!rclEQ.ok() || x11dead) {
 	    rclEQ.unlock();
 	    break;
 	}
 	    
-	list<string> modified;
-	list<string> deleted;
-
 	// Process event queue
 	while (!rclEQ.empty()) {
 	    // Retrieve event
@@ -334,20 +336,30 @@ bool startMonitor(RclConfig *conf, int opts)
 	// Unlock queue before processing lists
 	rclEQ.unlock();
 
-	// Process
-	if (!modified.empty()) {
-	    if (!indexfiles(conf, modified))
-		break;
-	    didsomething = true;
-	}
-	if (!deleted.empty()) {
-	    if (!purgefiles(conf, deleted))
-		break;
-	    didsomething = true;
-	}
+	// Process. We don't do this everytime but let the lists accumulate
+        // a little, this saves processing.
+        time_t now = time(0);
+        if (now - lastixtime > ixinterval) {
+            lastixtime = now;
+            if (!modified.empty()) {
+                modified.sort();
+                modified.unique();
+                if (!indexfiles(conf, modified))
+                    break;
+                modified.clear();
+                didsomething = true;
+            }
+            if (!deleted.empty()) {
+                deleted.sort();
+                deleted.unique();
+                if (!purgefiles(conf, deleted))
+                    break;
+                deleted.clear();
+                didsomething = true;
+            }
+        }
 
 	// Recreate the auxiliary dbs every hour at most.
-	const int auxinterval = 60 *60;
 	if (didsomething && time(0) - lastauxtime > auxinterval) {
 	    lastauxtime = time(0);
 	    didsomething = false;
@@ -362,6 +374,7 @@ bool startMonitor(RclConfig *conf, int opts)
 	// Lock queue before waiting again
 	rclEQ.lock();
     }
+    LOGDEB(("Rclmonprc: calling queue setTerminate\n"));
     rclEQ.setTerminate();
     // Wait for receiver thread before returning
     pthread_join(rcv_thrid, 0);
