@@ -18,7 +18,7 @@
 #define _GUIUTILS_H_INCLUDED_
 /* 
  * @(#$Id: guiutils.h,v 1.29 2008-10-03 08:09:35 dockes Exp $  (C) 2005 Jean-Francois Dockes 
- *                         jean-francois.dockes@wanadoo.fr
+ *                         jfd@recoll.org
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -86,8 +86,7 @@ class PrefsPack {
     bool startWithSortToolOpen;
     bool previewHtml;
     bool collapseDuplicates;
-    // Extra query indexes. This are encoded to base64 before storing
-    // to the qt settings file to avoid any bin string/ charset conv issues
+    // Extra query indexes. This are stored in the history file, not qt prefs
     list<string> allExtraDbs;
     list<string> activeExtraDbs;
     // Advanced search subdir restriction: we don't activate the last value
@@ -100,6 +99,10 @@ class PrefsPack {
     // Ignored file types in adv search (startup default)
     QStringList asearchIgnFilTyps;
     bool        fileTypesByCats;
+    // Words that are automatically turned to ext:xx specs in the query
+    // language entry. 
+    QString autoSuffs;
+    bool    autoSuffsEnable;
 
     // Synthetized abstract length and word context size
     int syntAbsLen;
