@@ -34,10 +34,6 @@
         <source>other</source>
         <translation>diğer</translation>
     </message>
-    <message>
-        <source>Cannot execute pure negative query. Please enter common terms in the &apos;any words&apos; field</source>
-        <translation>Tamamen negatif sorgu çalıştırılamaz. Lütfen &apos;herhangi bir sözcük&apos; alanına genel ifadeler girin</translation>
-    </message>
 </context>
 <context>
     <name>AdvSearchBase</name>
@@ -49,10 +45,6 @@
         <source>Search for &lt;br&gt;documents&lt;br&gt;satisfying:</source>
         <translation>Uyan &lt;br&gt;belgeleri&lt;br&gt;ara:</translation>
     </message>
-    <message>
-        <source>All non blank fields will be combined with OR or AND conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
-        <translation type="obsolete">Tüm boş alanlar VEYA ya da VE bağlaçları ile birleştirilecek. &lt;br&gt; &quot;Herhangi biri&quot; &quot;Tümü&quot; ve &quot;Hiçbiri&quot; alan tipleri basit sözcüklerin karışımını ve çift tırnak içine alınmış ifadeleri kabul edebilir.&lt;br&gt;Veri içermeyen alanlar yoksayılır.</translation>
-    </message>
     <message>
         <source>Delete clause</source>
         <translation>İfadeyi sil</translation>
@@ -132,10 +124,6 @@
 </context>
 <context>
     <name>Main</name>
-    <message>
-        <source>Configuration problem: </source>
-        <translation type="obsolete">Yapılandırma sorunu: </translation>
-    </message>
     <message>
         <source>Configuration problem (dynconf</source>
         <translation>Yapılandırma sorunu</translation>
@@ -165,10 +153,6 @@ Click Cancel if you want to edit the configuration file before indexing starts,
         <source>Cannot create temporary directory</source>
         <translation>Geçici dizin oluşturulamadı</translation>
     </message>
-    <message>
-        <source>File does not exist</source>
-        <translation type="obsolete">Dosya yok</translation>
-    </message>
     <message>
         <source>Cancel</source>
         <translation>İptal</translation>
@@ -210,49 +194,6 @@ Click Cancel if you want to edit the configuration file before indexing starts,
         <translation type="unfinished">Eşleşme Şa&amp;rtı</translation>
     </message>
 </context>
-<context>
-    <name>PreviewBase</name>
-    <message>
-        <source>Preview</source>
-        <translation type="obsolete">Önizle</translation>
-    </message>
-    <message>
-        <source>Preview 1</source>
-        <translation type="obsolete">Önizleme 1</translation>
-    </message>
-    <message>
-        <source>&amp;Search for:</source>
-        <translation type="obsolete">A&amp;ra:</translation>
-    </message>
-    <message>
-        <source>&amp;Next</source>
-        <translation type="obsolete">&amp;Sonraki</translation>
-    </message>
-    <message>
-        <source>Alt+N</source>
-        <translation type="obsolete">Alt+S</translation>
-    </message>
-    <message>
-        <source>&amp;Previous</source>
-        <translation type="obsolete">&amp;Önceki</translation>
-    </message>
-    <message>
-        <source>Alt+P</source>
-        <translation type="obsolete">Alt+Ö</translation>
-    </message>
-    <message>
-        <source>Clear</source>
-        <translation type="obsolete">Temizle</translation>
-    </message>
-    <message>
-        <source>Match &amp;Case</source>
-        <translation type="obsolete">Eşleşme Şa&amp;rtı</translation>
-    </message>
-    <message>
-        <source>Alt+C</source>
-        <translation type="obsolete">Alt+R</translation>
-    </message>
-</context>
 <context>
     <name>PreviewTextEdit</name>
     <message>
@@ -331,33 +272,6 @@ Click Cancel if you want to edit the configuration file before indexing starts,
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>QtGuiResListPager</name>
-    <message>
-        <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
-        <translation type="obsolete">&lt;p&gt;&lt;b&gt;Sonuç bulunamadı&lt;/b&gt;&lt;br&gt;</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation type="obsolete">Önceki</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation type="obsolete">Sonraki</translation>
-    </message>
-    <message>
-        <source>Unavailable document</source>
-        <translation type="obsolete">Erişilemez belge</translation>
-    </message>
-    <message>
-        <source>Preview</source>
-        <translation type="obsolete">Önizle</translation>
-    </message>
-    <message>
-        <source>(show query)</source>
-        <translation type="obsolete">(sorguyu göster)</translation>
-    </message>
-</context>
 <context>
     <name>RclMain</name>
     <message>
@@ -404,18 +318,10 @@ Click Cancel if you want to edit the configuration file before indexing starts,
         <source>Query results</source>
         <translation>Arama Sonuçları</translation>
     </message>
-    <message>
-        <source>Query results (sorted)</source>
-        <translation type="obsolete">Arama sonuçları (sıralanmış)</translation>
-    </message>
     <message>
         <source>Cannot retrieve document info from database</source>
         <translation>Veritabanından belge bilgileri alınamadı</translation>
     </message>
-    <message>
-        <source>Cannot access document file: </source>
-        <translation type="obsolete">Belge dosyasına erişilemedi: </translation>
-    </message>
     <message>
         <source>Warning</source>
         <translation>Uyarı</translation>
@@ -428,21 +334,11 @@ Click Cancel if you want to edit the configuration file before indexing starts,
         <source>This search is not active any more</source>
         <translation>Bu arama atrık etkin değil</translation>
     </message>
-    <message>
-        <source>No external viewer configured for mime type </source>
-        <translation type="obsolete">Mime tipi için bir dış gösterici ayarlanmamış</translation>
-    </message>
     <message>
         <source>Bad viewer command line for %1: [%2]
 Please check the mimeconf file</source>
         <translation>%1 için uygun olmayan komut: [%2]
 Lütfen mimeconf dosyasını kontrol edin</translation>
-    </message>
-    <message>
-        <source>The viewer specified in mimeconf for %1: %2 is not found.
-Do you want to start the  preferences dialog ?</source>
-        <translation type="obsolete">%1 için mimeconf dosyasında belirtilen gösterici: %2 bulunamadı.
-Tercihler penceresini  açmak ister misiniz?</translation>
     </message>
     <message>
         <source>Cannot extract document or create temporary file</source>
@@ -456,10 +352,6 @@ Tercihler penceresini  açmak ister misiniz?</translation>
         <source>About Recoll</source>
         <translation>Recoll Hakkında</translation>
     </message>
-    <message>
-        <source>Starting help browser </source>
-        <translation type="obsolete">Yardım tarayıcıyı başlat </translation>
-    </message>
     <message>
         <source>History data</source>
         <translation>Geçmiş verileri</translation>
@@ -551,6 +443,14 @@ Tercihler penceresini  açmak ister misiniz?</translation>
 Do you want to start the  preferences dialog ?</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Can&apos;t access file: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Can&apos;t uncompress file: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RclMainBase</name>
@@ -682,6 +582,26 @@ Do you want to start the  preferences dialog ?</source>
         <source>&amp;Show missing helpers</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>PgDown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Shift+Home, Ctrl+S, Ctrl+Q, Ctrl+S</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PgUp</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Full Screen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>F11</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ResList</name>
@@ -689,22 +609,10 @@ Do you want to start the  preferences dialog ?</source>
         <source>Result list</source>
         <translation>Sonuç listesi</translation>
     </message>
-    <message>
-        <source>Show query details</source>
-        <translation type="obsolete">Sorgu detaylarını göster</translation>
-    </message>
     <message>
         <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
         <translation type="unfinished">&lt;p&gt;&lt;b&gt;Sonuç bulunamadı&lt;/b&gt;&lt;br&gt;</translation>
     </message>
-    <message>
-        <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; out of at least &lt;b&gt;%3&lt;/b&gt; for </source>
-        <translation type="obsolete">Toplam &lt;b&gt;%3&lt;/b&gt; sonucun &lt;b&gt;%1-%2&lt;/b&gt; arası, sorgu </translation>
-    </message>
-    <message>
-        <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; for </source>
-        <translation type="obsolete">Sonuçlar &lt;b&gt;%1-%2&lt;/b&gt; arası, sorgu </translation>
-    </message>
     <message>
         <source>(show query)</source>
         <translation>(sorguyu göster)</translation>
@@ -725,10 +633,6 @@ Do you want to start the  preferences dialog ?</source>
         <source>&amp;Preview</source>
         <translation>&amp;Önizle</translation>
     </message>
-    <message>
-        <source>&amp;Edit</source>
-        <translation>&amp;Düzenle</translation>
-    </message>
     <message>
         <source>Copy &amp;File Name</source>
         <translation>&amp;Dosya Adını Kopyala</translation>
@@ -741,10 +645,6 @@ Do you want to start the  preferences dialog ?</source>
         <source>Find &amp;similar documents</source>
         <translation>Benzer belgeleri &amp;bul</translation>
     </message>
-    <message>
-        <source>P&amp;arent document/folder</source>
-        <translation type="obsolete">Ü&amp;st belge/dizin</translation>
-    </message>
     <message>
         <source>Query details</source>
         <translation>Sorgu detayları</translation>
@@ -761,14 +661,6 @@ Do you want to start the  preferences dialog ?</source>
         <source>Document history</source>
         <translation type="unfinished">Belge geçmişi</translation>
     </message>
-    <message>
-        <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; out of at least &lt;b&gt;%d&lt;/b&gt; for </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; for </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Preview</source>
         <translation type="unfinished">Önizle</translation>
@@ -793,6 +685,22 @@ Do you want to start the  preferences dialog ?</source>
         <source>&amp;Open Parent document/folder</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Open</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Documents</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>out of at least</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>for</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SSearch</name>
@@ -859,10 +767,6 @@ Do you want to start the  preferences dialog ?</source>
         <source>Start query</source>
         <translation>Sorguyu başlat</translation>
     </message>
-    <message>
-        <source>Choose type of search: any term, all terms, filename with possible wildcards.</source>
-        <translation type="obsolete">Arama tipini seçin: herhangi bir sözcük, tüm sözcükler, özel karakterler de kullanılabilen dosya adı.</translation>
-    </message>
     <message>
         <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
         <translation>Aranacak ifadeleri buraya girin. Geçerli sözcüğün tamamlanması için ESC SPACE kullanın.</translation>
@@ -976,8 +880,12 @@ Do you want to start the  preferences dialog ?</source>
         <translation>İfade</translation>
     </message>
     <message>
-        <source>Count</source>
-        <translation>Sayı</translation>
+        <source>No db info.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Doc. / Tot.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1014,6 +922,18 @@ Do you want to start the  preferences dialog ?</source>
         <source>No expansion found</source>
         <translation>Hiç genişleme bulunamadı</translation>
     </message>
+    <message>
+        <source>Term</source>
+        <translation type="unfinished">İfade</translation>
+    </message>
+    <message>
+        <source>Doc. / Tot.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Index: %1 documents, average length %2 terms</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UIPrefsDialog</name>
@@ -1088,22 +1008,6 @@ Do you want to start the  preferences dialog ?</source>
         <source>Maximum text size highlighted for preview (megabytes)</source>
         <translation>Önizlemede vurgulanacak en fazla metin boyutu (MB)</translation>
     </message>
-    <message>
-        <source>HTML help browser</source>
-        <translation type="obsolete">HTML yardım tarayıcı</translation>
-    </message>
-    <message>
-        <source>Select file</source>
-        <translation type="obsolete">Dosya seç</translation>
-    </message>
-    <message>
-        <source>Choose external viewer applications</source>
-        <translation type="obsolete">Dış gösterici uygulamaları seç</translation>
-    </message>
-    <message>
-        <source>Manage</source>
-        <translation type="obsolete">Yönet</translation>
-    </message>
     <message>
         <source>Auto-start simple search on whitespace entry.</source>
         <translation>Beyaz alan girdisi olduğunda basit aramayı otomatik olarak başlat.</translation>
@@ -1248,6 +1152,18 @@ Büyük boyutlu belgelerde yavaş olabilir.</translation>
         <source>Display category filter as toolbar instead of button panel (needs restart).</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>The words in the list will be automatically turned to ext:xxx clauses in the query language entry.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Query language magic file name suffixes.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewAction</name>
@@ -1443,10 +1359,6 @@ This will help searching very big text  files (ie: log files).</source>
         <source>No aspell usage</source>
         <translation>Aspell kullanımı yok</translation>
     </message>
-    <message>
-        <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful is aspell is absent or does not work. </source>
-        <translation type="obsolete">İfade gösterme aracı için heceleme yakınlığı oluşturma özelliğini kapatır.&lt;br&gt; Aspell olmadığında ya da çalışmadığında kullanışlıdır. </translation>
-    </message>
     <message>
         <source>Aspell language</source>
         <translation>Aspell dili</translation>
