@@ -33,10 +33,6 @@
         <source>other</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Cannot execute pure negative query. Please enter common terms in the &apos;any words&apos; field</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>AdvSearchBase</name>
@@ -444,6 +440,14 @@ Please check the mimeconf file</source>
 Do you want to start the  preferences dialog ?</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Can&apos;t access file: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Can&apos;t uncompress file: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RclMainBase</name>
@@ -575,6 +579,26 @@ Do you want to start the  preferences dialog ?</source>
         <source>&amp;Show missing helpers</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>PgDown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Shift+Home, Ctrl+S, Ctrl+Q, Ctrl+S</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PgUp</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Full Screen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>F11</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ResList</name>
@@ -590,10 +614,6 @@ Do you want to start the  preferences dialog ?</source>
         <source>&amp;Preview</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&amp;Edit</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Copy &amp;File Name</source>
         <translation type="unfinished"></translation>
@@ -626,14 +646,6 @@ Do you want to start the  preferences dialog ?</source>
         <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; out of at least &lt;b&gt;%d&lt;/b&gt; for </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; for </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Previous</source>
         <translation type="unfinished"></translation>
@@ -670,6 +682,22 @@ Do you want to start the  preferences dialog ?</source>
         <source>&amp;Open Parent document/folder</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Open</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Documents</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>out of at least</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>for</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SSearch</name>
@@ -849,7 +877,11 @@ Do you want to start the  preferences dialog ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Count</source>
+        <source>No db info.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Doc. / Tot.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -887,6 +919,18 @@ Do you want to start the  preferences dialog ?</source>
         <source>No expansion found</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Term</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Doc. / Tot.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Index: %1 documents, average length %2 terms</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UIPrefsDialog</name>
@@ -1103,6 +1147,18 @@ May be slow for big documents.</source>
         <source>Display category filter as toolbar instead of button panel (needs restart).</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>The words in the list will be automatically turned to ext:xxx clauses in the query language entry.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Query language magic file name suffixes.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewAction</name>
