@@ -946,7 +946,7 @@ void RclMain::saveDocToFile(int docnum)
 static bool lookForHtmlBrowser(string &exefile)
 {
     static const char *htmlbrowserlist = 
-	"opera konqueror firefox mozilla netscape epiphany";
+	"opera google-chrome konqueror firefox mozilla netscape epiphany";
     vector<string> blist;
     stringToTokens(htmlbrowserlist, blist, " ");
 
@@ -1003,7 +1003,7 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
 	cmdplusattr = rclconfig->getMimeViewerDef(doc.mimetype, apptag);
     }
 
-    if (cmdplusattr.length() == 0) {
+    if (cmdplusattr.empty()) {
 	QMessageBox::warning(0, "Recoll", 
 			     tr("No external viewer configured for mime type [")
 			     + doc.mimetype.c_str() + "]");
@@ -1029,30 +1029,30 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
 	return;
     }
 
-    // Look for the command to execute in the exec path and a few
-    // other places
+    // Look for the command to execute in the exec path and the filters 
+    // directory
     string cmdpath;
-    if (prefs.useDesktopOpen) {
-	// Findfilter searches the recoll filters directory in
-	// addition to the path. We store a copy of xdg-open there, to be 
-	// used as last resort
+    if (!ExecCmd::which(lcmd.front(), cmdpath)) {
 	cmdpath = rclconfig->findFilter(lcmd.front());
-	// Substitute path for cmd
-	if (!cmdpath.empty()) {
-	    lcmd.front() = cmdpath;
-	    cmd.erase();
-	    stringsToString(lcmd, cmd);
+	// findFilter returns its input param if the filter is not in
+	// the normal places. As we already looked in the path, we
+	// have no use for a simple command name here (as opposed to
+	// mimehandler which will just let execvp do its thing). Erase
+	// cmdpath so that the user dialog will be started further
+	// down.
+	if (!cmdpath.compare(lcmd.front())) 
+	    cmdpath.erase();
+
+	// Specialcase text/html because of the help browser need
+	if (cmdpath.empty() && !doc.mimetype.compare("text/html")) {
+	    if (lookForHtmlBrowser(cmdpath)) {
+		lcmd.clear();
+		lcmd.push_back(cmdpath);
+		lcmd.push_back("%u");
+	    }
 	}
-    } else {
-	ExecCmd::which(lcmd.front(), cmdpath);
     }
 
-    // Specialcase text/html because of the help browser need
-    if (cmdpath.empty() && !doc.mimetype.compare("text/html")) {
-	if (lookForHtmlBrowser(cmdpath)) {
-	    cmd = cmdpath + " %u";
-	}
-    }
 
     // Command not found: start the user dialog to help find another one:
     if (cmdpath.empty()) {
@@ -1077,12 +1077,13 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
 	return;
     }
 
-    // We may need a temp file, or not depending on the command arguments
-    // and the fact that this is a subdoc or not.
+    // We may need a temp file, or not, depending on the command
+    // arguments and the fact that this is a subdoc or not.
     bool wantsipath = (cmd.find("%i") != string::npos) || ignoreipath;
     bool wantsfile = cmd.find("%f") != string::npos;
     bool istempfile = false;
     string fn = fileurltolocalpath(doc.url);
+    string orgfn = fn;
     string url = doc.url;
 
     // If the command wants a file but this is not a file url, or
@@ -1128,7 +1129,10 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
         }
     }
 
-    // Substitute %xx inside prototype command
+    // Get rid of the command name. lcmd is now argv[1...n]
+    lcmd.pop_front();
+
+    // Substitute %xx inside arguments
     string efftime;
     if (!doc.dmtime.empty() || !doc.fmtime.empty()) {
         efftime = doc.dmtime.empty() ? doc.fmtime : doc.dmtime;
@@ -1137,22 +1141,30 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
     }
     // Try to keep the letters used more or less consistent with the reslist
     // paragraph format.
-    string ncmd;
     map<string, string> subs;
-    subs["D"] = escapeShell(efftime);
-    subs["f"] = escapeShell(fn);
-    subs["i"] = escapeShell(doc.ipath);
-    subs["M"] = escapeShell(doc.mimetype);
-    subs["U"] = escapeShell(url);
-    subs["u"] = escapeShell(url);
+    subs["D"] = efftime;
+    subs["f"] = fn;
+    subs["F"] = orgfn;
+    subs["i"] = doc.ipath;
+    subs["M"] = doc.mimetype;
+    subs["U"] = url;
+    subs["u"] = url;
     // Let %(xx) access all metadata.
     for (map<string,string>::const_iterator it = doc.meta.begin();
          it != doc.meta.end(); it++) {
-        subs[it->first] = escapeShell(it->second);
+        subs[it->first] = it->second;
+    }
+    string ncmd;
+    for (list<string>::iterator it = lcmd.begin(); 
+         it != lcmd.end(); it++) {
+        pcSubst(*it, ncmd, subs);
+        LOGDEB(("%s->%s\n", it->c_str(), ncmd.c_str()));
+        *it = ncmd;
     }
 
+    // Also substitute inside the unsplitted command line and display
+    // in status bar
     pcSubst(cmd, ncmd, subs);
-
     ncmd += " &";
     QStatusBar *stb = statusBar();
     if (stb) {
@@ -1166,11 +1178,11 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
 
     if (!istempfile)
 	historyEnterDoc(g_dynconf, doc.meta[Rcl::Doc::keyudi]);
-    
-    // We should actually monitor these processes so that we can
-    // delete the temp files when they exit
-    LOGDEB(("Executing: [%s]\n", ncmd.c_str()));
-    system(ncmd.c_str());
+
+    // We keep pushing back and never deleting. This can't be good...
+    ExecCmd *ecmd = new ExecCmd;
+    m_viewers.push_back(ecmd);
+    ecmd->startExec(cmdpath, lcmd, false, false);
 }
 
 void RclMain::startManual()
@@ -1328,6 +1340,10 @@ bool RclMain::eventFilter(QObject *, QEvent *event)
             resList->resultPageFirst();
             return true;
         } 
+    } else if (event->type() == QEvent::Show)  {
+	LOGDEB2(("RclMain::eventFilter: Show\n"));
+	// move the focus to the search entry on show
+	sSearch->queryText->setFocus();
     }
     return false;
 }
