@@ -127,8 +127,9 @@ ResList::~ResList()
 #endif
     static const char* strings[] = {
 	QT_TR_NOOP("<p><b>No results found</b><br>"),
-	QT_TR_NOOP("Documents <b>%d-%d</b> out of at least <b>%d</b> for "),
-	QT_TR_NOOP("Documents <b>%d-%d</b> for "),
+	QT_TR_NOOP("Documents"),
+	QT_TR_NOOP("out of at least"),
+	QT_TR_NOOP("for"),
 	QT_TR_NOOP("Previous"),
 	QT_TR_NOOP("Next"),
 	QT_TR_NOOP("Unavailable document"),
@@ -639,7 +640,7 @@ RCLPOPUP *ResList::createPopupMenu(const QPoint& pos)
 	return 0;
     RCLPOPUP *popup = new RCLPOPUP(this);
     popup->insertItem(tr("&Preview"), this, SLOT(menuPreview()));
-    popup->insertItem(tr("&Edit"), this, SLOT(menuEdit()));
+    popup->insertItem(tr("&Open"), this, SLOT(menuEdit()));
     popup->insertItem(tr("Copy &File Name"), this, SLOT(menuCopyFN()));
     popup->insertItem(tr("Copy &URL"), this, SLOT(menuCopyURL()));
     Rcl::Doc doc;
@@ -708,11 +709,17 @@ void ResList::menuCopyFN()
     Rcl::Doc doc;
     if (getDoc(m_popDoc, doc)) {
 	LOGDEB(("menuCopyFN: Got doc, fn: [%s]\n", doc.url.c_str()));
-	// Our urls currently always begin with "file://"
-	QApplication::clipboard()->setText(doc.url.c_str()+7, 
-					   QClipboard::Selection);
-	QApplication::clipboard()->setText(doc.url.c_str()+7, 
-					   QClipboard::Clipboard);
+	// Our urls currently always begin with "file://" 
+        //
+        // Problem: setText expects a QString. Passing a (const char*)
+        // as we used to do causes an implicit conversion from
+        // latin1. File are binary and the right approach would be no
+        // conversion, but it's probably better (less worse...) to
+        // make a "best effort" tentative and try to convert from the
+        // locale's charset than accept the default conversion.
+        QString qfn = QString::fromLocal8Bit(doc.url.c_str()+7);
+	QApplication::clipboard()->setText(qfn, QClipboard::Selection);
+	QApplication::clipboard()->setText(qfn, QClipboard::Clipboard);
     }
 }
 void ResList::menuCopyURL()
