@@ -79,10 +79,39 @@ void SSearch::searchTextChanged(const QString& text)
 void SSearch::searchTypeChanged(int typ)
 {
     LOGDEB(("Search type now %d\n", typ));
+    // Adjust context help
     if (typ == SST_LANG)
 	HelpClient::installMap(this->name(), "RCL.SEARCH.LANG");
     else 
 	HelpClient::installMap(this->name(), "RCL.SEARCH.SIMPLE");
+
+    // Also fix tooltips
+    switch (typ) {
+    case SST_LANG:
+        QToolTip::add(queryText,
+"Enter query language expression. Cheat sheet:<br>\n"
+"<i>term1 term2</i> : 'term1' and 'term2' in any field.<br>\n"
+"<i>field:term1</i> : 'term1' in field 'field'.<br>\n"
+" Standard field names/synonyms:<br>\n"
+"  title/subject/caption, author/from, recipient/to, filename, ext.<br>\n"
+" Pseudo-fields: dir, mime/format, type/rclcat, date.<br>\n"
+" Two date interval exemples: 2009-03-01/2009-05-20  2009-03-01/P2M.<br>\n"
+"<i>term1 term2 OR term3</i> : term1 AND (term2 OR term3).<br>\n"
+"  No actual parentheses allowed.<br>\n"
+"<i>\"term1 term2\"</i> : phrase (must occur exactly). Possible modifiers:<br>\n"
+"<i>\"term1 term2\"p</i> : unordered proximity search with default distance.<br>\n"
+"Use <b>Show Query</b> link when in doubt about result and see manual (&lt;F1>) for more detail.\n"
+            );
+        break;
+    case SST_FNM:
+        QToolTip::add(queryText, "Enter file name wildcard expression.");
+        break;
+    case SST_ANY:
+    case SST_ALL:
+    default:
+        QToolTip::add(queryText, 
+    "Enter search terms here. Type ESC SPC for completions of current term.");
+    }
 }
 
 void SSearch::startSimpleSearch()
@@ -102,7 +131,10 @@ void SSearch::startSimpleSearch()
 
     if (tp == SST_LANG) {
 	string reason;
-	sdata = wasaStringToRcl(u8, reason);
+        if (prefs.autoSuffsEnable)
+            sdata = wasaStringToRcl(u8, reason, (const char *)prefs.autoSuffs.utf8());
+        else
+            sdata = wasaStringToRcl(u8, reason);
 	if (sdata == 0) {
 	    QMessageBox::warning(0, "Recoll", tr("Bad query string") +
 				 QString::fromAscii(reason.c_str()));
@@ -233,17 +265,17 @@ void SSearch::completion()
 
     // Query database
     const int max = 100;
-    list<Rcl::TermMatchEntry> strs;
+    Rcl::TermMatchResult tmres;
     string stemLang = (const char *)prefs.queryStemLang.ascii();
     if (stemLang == "ALL") {
 	rclconfig->getConfParam("indexstemminglanguages", stemLang);
     }
-    if (!rcldb->termMatch(Rcl::Db::ET_WILD, stemLang, s, strs, max) || 
-	strs.size() == 0) {
+    if (!rcldb->termMatch(Rcl::Db::ET_WILD, stemLang, s, tmres, max) || 
+	tmres.entries.size() == 0) {
 	QApplication::beep();
 	return;
     }
-    if (strs.size() == (unsigned int)max) {
+    if (tmres.entries.size() == (unsigned int)max) {
 	QMessageBox::warning(0, "Recoll", tr("Too many completions"));
 	return;
     }
@@ -251,13 +283,13 @@ void SSearch::completion()
     // If list from db is single word, insert it, else ask user to select
     QString res;
     bool ok = false;
-    if (strs.size() == 1) {
-	res = QString::fromUtf8(strs.begin()->term.c_str());
+    if (tmres.entries.size() == 1) {
+	res = QString::fromUtf8(tmres.entries.begin()->term.c_str());
 	ok = true;
     } else {
 	QStringList lst;
-	for (list<Rcl::TermMatchEntry>::iterator it=strs.begin(); 
-	     it != strs.end(); it++) {
+	for (list<Rcl::TermMatchEntry>::iterator it = tmres.entries.begin(); 
+	     it != tmres.entries.end(); it++) {
 	    lst.push_back(QString::fromUtf8(it->term.c_str()));
 	}
 	res = QInputDialog::getItem(tr("Completions"),
