@@ -17,6 +17,8 @@ static char rcsid[] = "@(#$Id: uiprefs_w.cpp,v 1.26 2008-10-03 08:09:36 dockes E
  *   Free Software Foundation, Inc.,
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
+#include "autoconfig.h"
+
 #include <sys/stat.h>
 
 #include <string>
@@ -156,6 +158,9 @@ void UIPrefsDialog::setFromPrefs()
     replAbsCB->setEnabled(prefs.queryBuildAbstract);
     replAbsCB->setChecked(prefs.queryReplaceAbstract);
 
+    autoSuffsCB->setChecked(prefs.autoSuffsEnable);
+    autoSuffsLE->setText(prefs.autoSuffs);
+
     // Initialize the extra indexes listboxes
     idxLV->clear();
     for (list<string>::iterator it = prefs.allExtraDbs.begin(); 
@@ -221,6 +226,10 @@ void UIPrefsDialog::accept()
     prefs.syntAbsLen = syntlenSB->value();
     prefs.syntAbsCtx = syntctxSB->value();
 
+    
+    prefs.autoSuffsEnable = autoSuffsCB->isChecked();
+    prefs.autoSuffs = autoSuffsLE->text();
+
     QListViewItemIterator it(idxLV);
     prefs.allExtraDbs.clear();
     prefs.activeExtraDbs.clear();
