@@ -29,6 +29,8 @@ static char rcsid[] = "@(#$Id: recollq.cpp,v 1.22 2008-12-17 08:01:40 dockes Exp
 #include <limits.h>
 
 #include <iostream>
+#include <list>
+#include <string>
 using namespace std;
 
 #include "rcldb.h"
@@ -42,19 +44,11 @@ using namespace std;
 #include "internfile.h"
 #include "wipedir.h"
 #include "transcode.h"
+#include "textsplit.h"
 
-bool dump_contents(RclConfig *rclconfig, string& tmpdir, Rcl::Doc& idoc)
+bool dump_contents(RclConfig *rclconfig, TempDir& tmpdir, Rcl::Doc& idoc)
 {
-    if (tmpdir.empty() || access(tmpdir.c_str(), 0) < 0) {
-	string reason;
-	if (!maketmpdir(tmpdir, reason)) {
-	    cerr << "Cannot create temporary directory: "
-		 << reason << endl;
-	    return false;
-	}
-    }
-    wipedir(tmpdir);
-    FileInterner interner(idoc, rclconfig, tmpdir, 
+    FileInterner interner(idoc, rclconfig, tmpdir,
                           FileInterner::FIF_forPreview);
     Rcl::Doc fdoc;
     string ipath = idoc.ipath;
@@ -69,6 +63,7 @@ bool dump_contents(RclConfig *rclconfig, string& tmpdir, Rcl::Doc& idoc)
 
 static char *thisprog;
 static char usage [] =
+" -P: Show date span for documents in index\n"
 " [-o|-a|-f] <query string>\n"
 " Runs a recoll query and displays result lines. \n"
 "  Default: will interpret the argument(s) as a xesam query string\n"
@@ -88,6 +83,7 @@ static char usage [] =
 "    -A : output the document abstracts\n"
 "    -S fld : sort by field name\n"
 "    -D : sort descending\n"
+"    -i <dbdir> : additional index, several can be given\n"
 ;
 static void
 Usage(void)
@@ -114,12 +110,15 @@ static int     op_flags;
 #define OPT_S     0x2000
 #define OPT_s     0x4000
 #define OPT_A     0x8000
+#define OPT_i     0x10000
+#define OPT_P     0x20000
 
 int recollq(RclConfig **cfp, int argc, char **argv)
 {
     string a_config;
     string sortfield;
     string stemlang("english");
+    list<string> extra_dbs;
 
     int limit = 2000;
     thisprog = argv[0];
@@ -141,6 +140,9 @@ int recollq(RclConfig **cfp, int argc, char **argv)
             case 'd':   op_flags |= OPT_d; break;
             case 'D':   op_flags |= OPT_D; break;
             case 'f':   op_flags |= OPT_f; break;
+	    case 'i':	op_flags |= OPT_i; if (argc < 2)  Usage();
+		extra_dbs.push_back(*(++argv));
+		argc--; goto b1;
             case 'l':   op_flags |= OPT_l; break;
             case 'm':   op_flags |= OPT_m; break;
 	    case 'n':	op_flags |= OPT_n; if (argc < 2)  Usage();
@@ -148,6 +150,7 @@ int recollq(RclConfig **cfp, int argc, char **argv)
 		if (limit <= 0) limit = INT_MAX;
 		argc--; goto b1;
             case 'o':   op_flags |= OPT_o; break;
+            case 'P':   op_flags |= OPT_P; break;
             case 'q':   op_flags |= OPT_q; break;
 	    case 'S':	op_flags |= OPT_S; if (argc < 2)  Usage();
 		sortfield = *(++argv);
@@ -161,13 +164,6 @@ int recollq(RclConfig **cfp, int argc, char **argv)
     b1: argc--; argv++;
     }
 
-    if (argc < 1) {
-	Usage();
-    }
-    string qs = *argv++;argc--;
-    while (argc > 0) {
-	qs += string(" ") + *argv++;argc--;
-    }
     string reason;
     *cfp = recollinit(0, 0, reason, &a_config);
     RclConfig *rclconfig = *cfp;
@@ -176,6 +172,46 @@ int recollq(RclConfig **cfp, int argc, char **argv)
 	exit(1);
     }
 
+    if (argc < 1 && !(op_flags & OPT_P)) {
+	Usage();
+    }
+
+    Rcl::Db rcldb(rclconfig);
+    if (!extra_dbs.empty()) {
+        for (list<string>::iterator it = extra_dbs.begin();
+             it != extra_dbs.end(); it++) {
+            if (!rcldb.addQueryDb(*it)) {
+                cerr << "Can't add index: " << *it << endl;
+                exit(1);
+            }
+        }
+    }
+
+    if (!rcldb.open(Rcl::Db::DbRO)) {
+	cerr << "Cant open database in " << rclconfig->getDbDir() << 
+	    " reason: " << rcldb.getReason() << endl;
+	exit(1);
+    }
+
+    if (op_flags & OPT_P) {
+        int minyear, maxyear;
+        if (!rcldb.maxYearSpan(&minyear, &maxyear)) {
+            cerr << "maxYearSpan failed: " << rcldb.getReason() << endl;
+            exit(1);
+        } else {
+            cout << "Min year " << minyear << " Max year " << maxyear << endl;
+            exit(0);
+        }
+    }
+
+    if (argc < 1) {
+	Usage();
+    }
+    string qs = *argv++;argc--;
+    while (argc > 0) {
+	qs += string(" ") + *argv++;argc--;
+    }
+
     {
 	string uq;
 	string charset = rclconfig->getDefCharset(true);
@@ -190,14 +226,6 @@ int recollq(RclConfig **cfp, int argc, char **argv)
 	qs = uq;
     }
 
-
-    Rcl::Db rcldb(rclconfig);
-    if (!rcldb.open(Rcl::Db::DbRO)) {
-	cerr << "Cant open database in " << rclconfig->getDbDir() << 
-	    " reason: " << rcldb.getReason() << endl;
-	exit(1);
-    }
-
     Rcl::SearchData *sd = 0;
 
     if (op_flags & (OPT_a|OPT_o|OPT_f)) {
@@ -244,7 +272,12 @@ int recollq(RclConfig **cfp, int argc, char **argv)
 	    cout << cnt << " results (printing  " << limit << " max):" << endl;
     }
 
-    string tmpdir;
+    TempDir tmpdir;
+    if (!tmpdir.ok()) {
+	cerr << "Can't create temporary directory: " << 
+	    tmpdir.getreason() << endl;
+	exit(1);
+    }
     for (int i = 0; i < limit; i++) {
 	Rcl::Doc doc;
 	if (!query.getDoc(i, doc))
@@ -281,14 +314,6 @@ int recollq(RclConfig **cfp, int argc, char **argv)
         }	
     }
 
-    // Maybe clean up temporary directory
-    if (tmpdir.length()) {
-	wipedir(tmpdir);
-	if (rmdir(tmpdir.c_str()) < 0) {
-	    cerr << "Cannot clear temp dir " << tmpdir << endl;
-	}
-    }
-
     return 0;
 }
 
