@@ -20,6 +20,7 @@ static char rcsid[] = "@(#$Id: wasatorcl.cpp,v 1.18 2008-12-05 11:09:31 dockes E
 #include <cstdio>
 #include <string>
 #include <list>
+#include <algorithm>
 using std::string;
 using std::list;
 
@@ -31,22 +32,24 @@ using std::list;
 #include "smallut.h"
 #include "rclconfig.h"
 #include "refcntr.h"
+#include "textsplit.h"
 
-Rcl::SearchData *wasaStringToRcl(const string &qs, string &reason)
+Rcl::SearchData *wasaStringToRcl(const string &qs, string &reason, 
+                                 const string& autosuffs)
 {
     StringToWasaQuery parser;
     WasaQuery *wq = parser.stringToQuery(qs, reason);
     if (wq == 0) 
 	return 0;
-    Rcl::SearchData *rq = wasaQueryToRcl(wq);
+    Rcl::SearchData *rq = wasaQueryToRcl(wq, autosuffs);
     if (rq == 0) {
-	reason = "Failed translating wasa query structure to recoll";
+	reason = "Failed translating xesam query structure to recoll";
 	return 0;
     }
     return rq;
 }
 
-Rcl::SearchData *wasaQueryToRcl(WasaQuery *wasa)
+Rcl::SearchData *wasaQueryToRcl(WasaQuery *wasa, const string& autosuffs)
 {
     if (wasa == 0)
 	return 0;
@@ -74,8 +77,9 @@ Rcl::SearchData *wasaQueryToRcl(WasaQuery *wasa)
 	case WasaQuery::OP_LEAF: {
 	    LOGDEB2(("wasaQueryToRcl: leaf clause [%s]:[%s]\n", 
 		     (*it)->m_fieldspec.c_str(), (*it)->m_value.c_str()));
-	    unsigned int mods = (unsigned int)(*it)->m_modifiers;
+
 	    // Special cases (mime, category, dir filter ...). Not pretty.
+
 	    if (!stringicmp("mime", (*it)->m_fieldspec) ||
 		!stringicmp("format", (*it)->m_fieldspec)
 		) {
@@ -102,6 +106,36 @@ Rcl::SearchData *wasaQueryToRcl(WasaQuery *wasa)
 		break;
 	    } 
 
+            // Change terms found in the "autosuffs" list into "ext"
+            // field queries
+            if ((*it)->m_fieldspec.empty() && !autosuffs.empty()) {
+                vector<string> asfv;
+                if (stringToStrings(autosuffs, asfv)) {
+                    if (find_if(asfv.begin(), asfv.end(), 
+                                StringIcmpPred((*it)->m_value)) != asfv.end()) {
+                        (*it)->m_fieldspec = "ext";
+                        (*it)->m_modifiers |= WasaQuery::WQM_NOSTEM;
+                    }
+                }
+            }
+
+            // Handle "date" spec
+	    if (!stringicmp("date", (*it)->m_fieldspec)) {
+                DateInterval di;
+                if (!parsedateinterval((*it)->m_value, &di)) {
+                    LOGERR(("wasaQueryToRcl: bad date interval format\n"));
+                    // Process rest of query anyway ?
+                    break;
+                }
+                LOGDEB(("wasaQueryToRcl:: date span:  %d-%d-%d/%d-%d-%d\n",
+                        di.y1,di.m1,di.d1, di.y2,di.m2,di.d2))
+		sdata->setDateSpan(&di);
+		break;
+	    } 
+
+            // "Regular" processing follows:
+	    unsigned int mods = (unsigned int)(*it)->m_modifiers;
+
 	    if (TextSplit::hasVisibleWhite((*it)->m_value)) {
 		int slack = (mods & WasaQuery::WQM_PHRASESLACK) ? 10 : 0;
 		Rcl::SClType tp = Rcl::SCLT_PHRASE;
@@ -121,8 +155,7 @@ Rcl::SearchData *wasaQueryToRcl(WasaQuery *wasa)
 		LOGERR(("wasaQueryToRcl: out of memory\n"));
 		return 0;
 	    }
-	    if ((*it)->m_modifiers & WasaQuery::WQM_NOSTEM) {
-		fprintf(stderr, "Setting NOSTEM\n");
+	    if (mods & WasaQuery::WQM_NOSTEM) {
 		nclause->setModifiers(Rcl::SearchDataClause::SDCM_NOSTEMMING);
 	    }
 	    sdata->addClause(nclause);
@@ -131,7 +164,7 @@ Rcl::SearchData *wasaQueryToRcl(WasaQuery *wasa)
 	    
 	case WasaQuery::OP_EXCL:
 	    LOGDEB2(("wasaQueryToRcl: excl clause [%s]:[%s]\n", 
-		     (*it)->m_fieldspec.c_str(), (*it)->m_value.c_str()));
+                    (*it)->m_fieldspec.c_str(), (*it)->m_value.c_str()));
 	    if (wasa->m_op != WasaQuery::OP_AND) {
 		LOGERR(("wasaQueryToRcl: negative clause inside OR list!\n"));
 		continue;
