@@ -23,6 +23,7 @@ static char rcsid[] = "@(#$Id: rcldb.cpp,v 1.154 2008-12-17 16:19:58 dockes Exp
 #include <fnmatch.h>
 #include <regex.h>
 #include <math.h>
+#include <time.h>
 
 #include <iostream>
 #include <string>
@@ -905,6 +906,22 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
         LOGDEB(("Db::addOrUpdate: split failed for file name\n"));
     splitter.basepos += splitter.curpos + 100;
 
+    // If the ipath is like a path, index the last element. This is
+    // for compound documents like zip and chm for which the filter
+    // uses the file path as ipath. 
+    if (!doc.ipath.empty() && 
+	doc.ipath.find_first_not_of("0123456789") != string::npos) {
+	string utf8ipathlast;
+	// There is no way in hell we could have an idea of the
+	// charset here, so let's hope it's ascii or utf-8. We call
+	// transcode to strip the bad chars and pray
+	if (transcode(path_getsimple(doc.ipath), utf8ipathlast,
+		      "UTF-8", "UTF-8")) {
+	    splitter.text_to_words(utf8ipathlast);
+	    splitter.basepos += splitter.curpos + 100;
+	}
+    }
+	    
     // Index textual metadata.  These are all indexed as text with
     // positions, as we may want to do phrase searches with them (this
     // makes no sense for keywords by the way).
@@ -987,7 +1004,8 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
 			doc.dmtime.c_str());
     struct tm *tm = localtime(&mtime);
     char buf[9];
-    sprintf(buf, "%04d%02d%02d",tm->tm_year+1900, tm->tm_mon + 1, tm->tm_mday);
+    snprintf(buf, 9, "%04d%02d%02d",
+	    tm->tm_year+1900, tm->tm_mon + 1, tm->tm_mday);
     newdocument.add_term("D" + string(buf)); // Date (YYYYMMDD)
     buf[6] = '\0';
     newdocument.add_term("M" + string(buf)); // Month (YYYYMM)
