@@ -8,7 +8,7 @@ static char rcsid[] = "@(#$Id: rclquery.cpp,v 1.11 2008-12-19 09:55:36 dockes Ex
 #include <list>
 #include <vector>
 
-#include "xapian/sorter.h"
+#include "xapian.h"
 
 #include "rcldb.h"
 #include "rcldb_p.h"
